@@ -21,7 +21,7 @@ class StatusCodeEnum(Enum):
 
     @property
     def code(self):
-        """获取状态码""""
+        """获取状态码"""
         return self.value[0]
 
     @property
